\name{pns}
\alias{pns}
\title{Principal Nested Spheres}
\description{Calculation of Principal Nested Spheres
}
\usage{
pns(x, sphere.type = "seq.test", alpha = 0.1, R = 100, nlast.small.sphere = 0)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{a (d + 1) x n data matrix where each column is a unit vector in S^d and n is the sample size.
}
  \item{sphere.type}{
  a character string specifying the type of sphere fitting method.
"seq.test"
specifies sequential tests to decide either "small" or "great";
"small"
specifies Principal Nested SMALL Sphere;
"great"
specifies Principal Nested GREAT Sphere (radius pi/2);
"BIC"
specifies BIC statistic to decide either "small" or "great"; and
"bi.sphere"
specifies Principal Nested GREAT Sphere for the first part and Principal Nested SMALL Sphere for The default is "seq.test".
} 
  \item{alpha}{significance level (0 < alpha < 1) used when sphere.type = "seq.test". The default is 0.1.
}
\item{R}{the number of bootstrap samples to be evaluated for the sequential test. The default is 100.}
\item{nlast.small.sphere}{the number of small spheres in the finishing part used when 
sphere.type = "bi.sphere".}
}
\value{A list with components
\item{resmat}{the residual matrix (X_PNS). Each entry in row k works like the kth principal component $PNS = the list with the following components.}
\item{radii}{the size (radius) of PNS.}
\item{orthaxis}{the orthogonal axis v_i of subspheres.}
\item{dist}{the distance r_i of subspheres}
\item{pvalues}{the p-values of LRT and parametric boostrap tests (if any).}
\item{ratio}{the estimated ratios. Now unavailable.}
\item{mean}{the location of the PNS mean.}
\item{sphere.type}{the type of method for fitting subspheres.}
\item{percent}{proportion of variances explained.}
}
\references{
Dryden, I.L., Kim, K. and Le, H. (2018). Principal nested shape spaces, with applications to molecular dynamics data.
Technical report. 

Jung, S., Dryden, I.L. and Marron, J.S. (2012). Analysis of principal nested spheres. Biometrika, 99, 551-568.
}
\author{Kwang-Rae Kim: R translation of Sungkyu Jung's matlab code}
\seealso{pns4pc}

\examples{

#  out <- pc2sphere(x = gorf.dat, n.pc = 2)
#  spheredata <- t(out$spheredata)
#  pns.out <- pns(x = spheredata)

}


\keyword{multivariate} 


